@@ -1,13 +1,8 @@
 /* Define if the ALSA output driver is used */
-#undef USE_ALSA
-/* Define if the ALSA PCM v2 tree is used */
-#undef ALSA_PCM_V2
-/* Define if we have an older alsa-lib that uses void * handles */
-#undef USE_ALSA_VOID
+#undef HAVE_ALSA_05
+#undef HAVE_ALSA_09
 
 #undef HAVE_ESD
-#undef HAVE_LIBGSL4
-#undef HAVE_LIBGSL
 
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
