@@ -3,7 +3,8 @@
  * 
  * Copyright (C) 1999 by Dave J. Andruczyk 
  * 
- * Based upon Code written by The Rasterman and DrMike from redhat.com
+ * Based on the original extace written by The Rasterman and Michael Fulbright
+ *  
  * 
  * This software comes under the GPL (GNU Public License)
  * You may freely copy,distribute etc. this as long as the source code
@@ -17,10 +18,10 @@ typedef enum
     HAMMING	= 1 << 1,
     HANNING	= 1 << 2,
     BLACKMAN	= 1 << 3,
-    GAUSSIAN	= 1 << 4,
-    WELCH	= 1 << 5,
-    PARZEN	= 1 << 6,
-    RECTANGULAR	= 1 << 7
+    BLACKMAN_HARRIS	= 1 << 4,
+    GAUSSIAN	= 1 << 5,
+    WELCH	= 1 << 6,
+    PARZEN	= 1 << 7,
+    RECTANGULAR	= 1 << 8
 }WindowFunction;
 
-
